package com.link.core.util.tianyu;

import com.link.core.cllog.LCLogger;
import com.link.core.util.StringUtils;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.SortedMap;
import java.util.TreeMap;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import org.apache.commons.beanutils.BeanUtils;
import sun.misc.BASE64Encoder;

public class TianYuCheckUtil {
   private static final String CHECK_URL = "csec.api.qcloud.com/v2/index.php";
   private static final String SECRET_ID = "111";
   private static final String SECRET_KEY = "111";

   public static Map<String, Object> checkLevel(AccountInfo accountInfo) throws Exception {
      if (accountInfo.getAccountType() == 0) {
         throw new Exception("请输入用户账号类型");
      } else if (StringUtils.isBlank(accountInfo.getUid())) {
         throw new Exception("请输入用户ID");
      } else if (StringUtils.isBlank(accountInfo.getUserIp())) {
         throw new Exception("请输入用户的外网 IP");
      } else if (accountInfo.getPostTime() == 0) {
         throw new Exception("请输入用户操作时间戳");
      } else {
         Map<String, String> args = BeanUtils.describe(accountInfo);
         String url = makeURL("GET", "ActivityAntiRush", "lj", "111", "111", args, "utf-8");
         Map<String, Object> res = sendGet(url, "");
         return res;
      }
   }

   public static String makeURL(String method, String action, String region, String secretId, String secretKey, Map<String, String> args, String charset) throws InvalidKeyException, NoSuchAlgorithmException, UnsupportedEncodingException {
      SortedMap<String, String> arguments = new TreeMap();
      arguments.putAll(args);
      arguments.put("Nonce", String.valueOf((int)(Math.random() * 2.147483647E9)));
      arguments.put("Action", action);
      arguments.put("Region", region);
      arguments.put("SecretId", secretId);
      arguments.put("Timestamp", String.valueOf(System.currentTimeMillis() / 1000L));
      arguments.put("Signature", hmacSHA1(secretKey, String.format("%s%s?%s", method, "csec.api.qcloud.com/v2/index.php", makeQueryString(arguments, (String)null))));
      return String.format("https://%s?%s", "csec.api.qcloud.com/v2/index.php", makeQueryString(arguments, charset));
   }

   public static String hmacSHA1(String key, String text) throws InvalidKeyException, NoSuchAlgorithmException {
      Mac mac = Mac.getInstance("HmacSHA1");
      mac.init(new SecretKeySpec(key.getBytes(), "HmacSHA1"));
      return encode(mac.doFinal(text.getBytes()));
   }

   private static String makeQueryString(Map<String, String> args, String charset) throws UnsupportedEncodingException {
      String url = "";
      Iterator var3 = args.entrySet().iterator();

      while(var3.hasNext()) {
         Map.Entry<String, String> entry = (Map.Entry)var3.next();
         if (!StringUtils.isBlank((String)entry.getValue()) && !"class".equalsIgnoreCase((String)entry.getKey())) {
            url = url + (String)entry.getKey() + "=" + (charset == null ? (String)entry.getValue() : URLEncoder.encode((String)entry.getValue(), charset)) + "&";
         }
      }

      return url.substring(0, url.length() - 1);
   }

   private static String encode(byte[] bstr) {
      String s = System.getProperty("line.separator");
      return (new BASE64Encoder()).encode(bstr).replaceAll(s, "");
   }

   public static Map<String, Object> sendGet(String url, String params) {
      BufferedReader br = null;
      Map<String, Object> result = new HashMap();

      try {
         String urlNameString = url;
         if (0 != params.length()) {
            String linkOperator = urlNameString.contains("?") ? "&" : "?";
            urlNameString = urlNameString + linkOperator + params;
         }

         HttpURLConnection connection = (HttpURLConnection)(new URL(urlNameString)).openConnection();
         connection.setRequestProperty("accept", "*/*");
         connection.setRequestProperty("connection", "Keep-Alive");
         connection.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
         connection.connect();
         Map<String, List<String>> header = connection.getHeaderFields();
         String body = readString(connection.getInputStream());
         result.put("success", true);
         result.put("result", body);
      } catch (Exception var8) {
         Exception e = var8;
         LCLogger.withException(e);
         result.put("success", false);
         result.put("result", e.getMessage());
      }

      return result;
   }

   private static String readString(InputStream is) {
      BufferedReader br = null;
      String content = "";

      try {
         String line;
         try {
            for(br = new BufferedReader(new InputStreamReader(is, "utf-8")); (line = br.readLine()) != null; content = content + line) {
            }
         } catch (IOException var12) {
            IOException e = var12;
            LCLogger.withException(e);
         }
      } finally {
         try {
            if (br != null) {
               br.close();
            }
         } catch (Exception var11) {
            Exception e = var11;
            LCLogger.withException(e);
         }

      }

      return content;
   }
}
